@@ -1,6 +1,5 @@
 /*
- *  Copyright (C) 2005-2020 Team Kodi
- *  https://kodi.tv
+ *  Copyright (C) 2005-2021 Team Kodi (https://kodi.tv)
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  *  See LICENSE.md for more information.
@@ -410,15 +409,17 @@ PVR_ERROR cPVRClientNextPVR::OnSystemSleep()
 {
   m_bConnected = false;
   m_lastRecordingUpdateTime = std::numeric_limits<time_t>::max();
+  m_nextServerCheck = std::numeric_limits<time_t>::max();
   m_connectionState = PVR_CONNECTION_STATE_DISCONNECTED;
   return PVR_ERROR_NO_ERROR;
 }
 
 PVR_ERROR cPVRClientNextPVR::OnSystemWake()
 {
+  kodi::Log(ADDON_LOG_DEBUG, "NextPVR wake");
   // allow time for core to reset
   m_lastRecordingUpdateTime = time(nullptr) + 60;
-
+  m_nextServerCheck = 0;
   // don't trigger updates core does it
   SetConnectionState("Reconnect", PVR_CONNECTION_STATE_UNKNOWN);
 
@@ -793,7 +794,7 @@ bool cPVRClientNextPVR::IsServerStreaming()
   {
     return true;
   }
-  kodi::Log(ADDON_LOG_ERROR, "Unknown streaming state %d %d %d %d", m_nowPlaying, m_recordingBuffer->GetDuration(), !m_livePlayer);
+  kodi::Log(ADDON_LOG_ERROR, "Unknown streaming state %d %d %d", m_nowPlaying, m_recordingBuffer->GetDuration(), !m_livePlayer);
   return false;
 }
 
